<?php

namespace Kitt3n\AzureAdForSymfonyBundle\DependencyInjection;

use Symfony\Component\Config\Definition\Builder\TreeBuilder;
use Symfony\Component\Config\Definition\ConfigurationInterface;

/**
 * This is the class that validates and merges configuration from your app/config files.
 *
 * To learn more see {@link http://symfony.com/doc/current/cookbook/bundles/configuration.html}
 */
class Configuration implements ConfigurationInterface
{
    /**
     * {@inheritdoc}
     */
    public function getConfigTreeBuilder()
    {
        $treeBuilder = new TreeBuilder('azure_ad_for_symfony');
        $rootNode = $treeBuilder->getRootNode();

        // Here you should define the parameters that are allowed to
        // configure your bundle. See the documentation linked above for
        // more information on that topic.

        $rootNode
            ->children()

                ->booleanNode('active')->isRequired()->defaultValue(false)->end()

                ->arrayNode('oauth')
                    ->children()
                        ->scalarNode('client_id')->isRequired()->end()
                        ->scalarNode('client_secret')->isRequired()->end()
                        ->scalarNode('tenant')->isRequired()->end()
                        ->scalarNode('redirect_uri')->isRequired()->end()
                        ->scalarNode('url_authorize')->isRequired()->end()
                        ->scalarNode('url_access_token')->isRequired()->end()
                        ->scalarNode('url_resource_owner_details')->isRequired()->end()
                        ->scalarNode('scopes')->isRequired()->end()

                        /**
                         * Azure Active Directory / Groups
                         * Priority 1
                         */
                        ->arrayNode('groups')
                            ->children()
                                ->scalarNode('backend')->isRequired()->end()
                                ->scalarNode('frontend')->isRequired()->end()
                            ->end()
                        ->end()

                        /**
                         * App Registration / App Roles
                         * Priority 2
                         */
                        ->arrayNode('app_roles')
                            ->children()
                                ->scalarNode('backend')->end()
                                ->scalarNode('frontend')->end()
                            ->end()
                        ->end()

                        ->arrayNode('redirect_route')
                            ->children()
                                ->scalarNode('success')->end()
                            ->end()
                        ->end()

                    ->end()
                ->end()

                ->arrayNode('encryption')
                    ->children()
                        ->scalarNode('secret')->isRequired()->end()
                    ->end()
                ->end()

            ->end()
            ;

        return $treeBuilder;
    }
}
